from .verify import get_errors_fails, mark_incomplete, mark_complete
import os

task1_id = '6cb98012-99d5-4dab-82c7-3ba61f1e9aac' # Check out the requests users are sending to your system
task2_id = 'f65ab939-e4a3-4090-aa60-66ed53991941' # Run the API
task3_id = 'c8d2e785-04c2-4b3d-8c5c-0e93cd6631a9' # Decode the image
task4_id = '32699ae4-5d65-48ea-9411-1077cb4a4bbc' # Save the input image to the cloud
task5_id = '19b54de2-c555-472c-9124-9db33834f23d' # Take a look at some of the images in S3

# test_netcat(self):
# test_print_image_name(self):
# test_decoding_image(self):
# test_save_to_s3(self):
# test_check_images_in_s3(self):


if 'milestone1_p2.txt' in os.listdir('.'):
    errors = get_errors_fails('milestone1_p2.txt')
    # If there are no errors, mark everything as complete
    if len(errors) == 0:
        print('No errors found in milestone 1!')
        mark_complete(task1_id)
        mark_complete(task2_id)
        mark_complete(task3_id)
        mark_complete(task4_id)
        mark_complete(task5_id)

    # Check if hangman_solution.py is in the repo
    elif 'test_netcat' in errors:
        # mark_incomplete(task2_id, message='There is no hangman_solution.py file inside the hangman folder')
        mark_incomplete(task1_id)
        mark_incomplete(task2_id)
        mark_incomplete(task3_id)
        mark_incomplete(task4_id)
        mark_incomplete(task5_id)
        print(errors['test_netcat'])
    # Check if they are identical
    elif 'test_print_image_name' in errors:
        print("Task 1 looks good")
        mark_complete(task1_id)
        mark_incomplete(task2_id)
        mark_incomplete(task3_id)
        mark_incomplete(task4_id)
        mark_incomplete(task5_id)
        print(errors['test_print_image_name'])
    elif 'test_decoding_image' in errors:
        print("Tasks 1 and 2 look good")
        mark_complete(task1_id)
        mark_complete(task2_id)
        mark_incomplete(task3_id)
        mark_incomplete(task4_id)
        mark_incomplete(task5_id)
        print(errors['test_decoding_image'])
    elif 'test_save_to_s3' in errors:
        print("Tasks 1, 2, 3 look good")
        mark_complete(task1_id)
        mark_complete(task2_id)
        mark_complete(task3_id)
        mark_incomplete(task4_id)
        mark_incomplete(task5_id)
        print(errors['test_save_to_s3'])
    elif 'test_check_images_in_s3' in errors:
        print("Tasks 1, 2, 3, 4 look good")
        mark_complete(task1_id)
        mark_complete(task2_id)
        mark_complete(task3_id)
        mark_complete(task4_id)
        mark_incomplete(task5_id)
        print(errors['test_check_images_in_s3'])
    else:
        mark_complete(task1_id)
        mark_complete(task2_id)
        mark_complete(task3_id)
        mark_complete(task4_id)
        mark_complete(task5_id)

else:
    mark_incomplete(task1_id)
    mark_incomplete(task2_id)
    mark_incomplete(task3_id)
    mark_incomplete(task4_id)
    mark_incomplete(task5_id)
    print('milestone1_p2.txt is not in the directory')


from .verify import get_errors_fails, mark_incomplete, mark_complete
import os

task1_id = '6cb98012-99d5-4dab-82c7-3ba61f1e9aac' # Check out the requests users are sending to your system
task2_id = 'f65ab939-e4a3-4090-aa60-66ed53991941' # Run the API
task3_id = 'c8d2e785-04c2-4b3d-8c5c-0e93cd6631a9' # Decode the image
task4_id = '32699ae4-5d65-48ea-9411-1077cb4a4bbc' # Save the input image to the cloud
task5_id = '19b54de2-c555-472c-9124-9db33834f23d' # Take a look at some of the images in S3

# test_model_presence
# test_readme_presence

if 'milestone1_p1.txt' in os.listdir('.'):
    errors = get_errors_fails('milestone1_p1.txt')
    print(errors['test_presence_api'])
    mark_incomplete(task1_id)
    mark_incomplete(task2_id)
    mark_incomplete(task3_id)
    mark_incomplete(task4_id)
    mark_incomplete(task5_id)
else:
    print('Something went wrong')


import os
import requests
import json

user_id = os.environ['USER_ID']
token = os.environ['PROD_API_TOKEN']
url_api = os.environ['VERIFY_ENDPOINT']
headers = {'x-api-key': f"{token}"}

def get_errors_fails(report_path: str):
    with open(report_path, 'r') as f:
        report = f.read()

    list_fails = report.split('======================================================================')

    if len(list_fails) > 1:
        list_fails = list_fails[1:]

    fail_error = [fail.split('----------------------------------------------------------------------')[0]
                for fail in list_fails]
    
    error_dict = {}

    for error in list_fails:
        if error.startswith('\nERROR'):
            fail_error = error.split('----------------------------------------------------------------------')[0].split('ERROR: ')[1].split(' (')[0]
            message = ' '.join(error.split('----------------------------------------------------------------------')[1].split(': ')[-2:]).strip()
            error_dict[fail_error] = message
        elif error.startswith('\nFAIL'):
            fail_error = error.split('----------------------------------------------------------------------')[0].split('FAIL: ')[1].split(' (')[0]
            message = error.split('----------------------------------------------------------------------')[1].split(' : ')[1].strip()
            error_dict[fail_error] = message

    return error_dict

def mark_complete(task_id: str, message=None):
    data = {
            'task_id': task_id,
            'user_id': user_id,
            }
    if message:
        data['message'] = message

    r = requests.post(url_api, headers=headers, data=json.dumps(data))
    assert r.status_code == 200

def mark_incomplete(task_id: str, message=None):
    data = {
            'task_id': task_id,
            'user_id': user_id,
            'complete': False
            }
    if message:
        data['message'] = message

    r = requests.post(url_api, headers=headers, data=json.dumps(data))

    assert r.status_code == 200


from ast import arg
from re import sub
import unittest
import os
from urllib.request import urlopen
from subprocess import Popen, PIPE, STDOUT

# print(process)

class ImageSegmentationTestCase(unittest.TestCase):
    def setUp(self) -> None:
        api_script = 'api.py'
        with open(api_script, 'r') as f:
            self.api_code = f.read()
        self.user_id = os.environ['USER_ID']


    def test_netcat(self):
        number_calls = int(os.environ['NETCAT_CALLS'])
        self.assertGreater(number_calls, 0, 'You should have called netcat server to listen port 8080 at least once')
    
    def test_print_image_name(self):
        self.assertIn('print(image_name)', self.api_code, 'You should print the image name in the api.py file. If you have, make sure it has the right syntax')

    def test_decoding_image(self):
        self.assertIn('decode_image(image)', self.api_code, 'You should call the decode_image on the image in the api.py file. If you have, make sure it has the right syntax')
        self.assertIn('decoded_image', self.api_code, 'You haven\'t assigned the decoded image to any variable. If you have, make sure the variable is called "decoded_image"')
        self.assertIn('decoded_image.size', self.api_code, 'You are not printing the size of the decoded image. If you are, remember that the variable should be named "decoded_image"')
    
    def test_save_to_s3(self):
        bucket_name = self.user_id + '-data'
        self.assertIn(bucket_name, self.api_code, 'You are not using the right name for your bucket. The name of the bucket should look like an id followed by -data. Something like xxxx-xxxxx-xxxx-xxxx-data')
        number_occurrences = self.api_code.count('save_image_to_s3')
        self.assertGreater(number_occurrences, 1, 'You should have called the "save_image_to_s3" function in the api.py file. If you have, make sure it has the right syntax')

    def test_check_images_in_s3(self):
        number_input_images = int(os.environ['NUMBER_INPUT_IMAGES'])
        self.assertGreater(number_input_images, 0, 'You should have uploaded at least one image to S3. If you have, make sure you have the right number of images in your bucket')

if __name__ == '__main__':

    unittest.main(verbosity=2)
    


import unittest
import os

class ImageSegmentationTestCase(unittest.TestCase):
    def test_presence_api(self):
        api_script = 'api.py'
        self.assertIn(api_script, os.listdir('.'), 'There is no api.py file in your project folder. If it is there, make sure it is named correctly, and that it is in the main folder. If you accidentally deleted it, you can type "reset_script"')

if __name__ == '__main__':

    unittest.main(verbosity=2)
    


import setuptools

setuptools.setup(
    name="image-segmentation-marking-aicore",
    version="1.0.3",
    author="Ivan Ying",
    author_email="ivan@theaicore.com",
    description="An automated marking system for the image segmentation scenario",
    packages=setuptools.find_packages(),
    python_requires=">=3.6",
    install_requires=['requests']
)